@@ -48,11 +48,14 @@ use overload
     'int'  => \&overload_int,
     'abs'  => \&overload_abs;
 
-    @Math::GMPq::EXPORT_OK = qw(
-GMPQ_PV_NV_BUG
+    my @untagged = qw(
 __GNU_MP_VERSION __GNU_MP_VERSION_MINOR __GNU_MP_VERSION_PATCHLEVEL
 __GNU_MP_RELEASE __GMP_CC __GMP_CFLAGS
 IOK_flag NOK_flag POK_flag
+    );
+
+my @tagged = qw(
+GMPQ_PV_NV_BUG
 Rmpq_abs Rmpq_add Rmpq_canonicalize Rmpq_clear Rmpq_cmp Rmpq_cmp_si Rmpq_cmp_ui
 Rmpq_cmp_z Rmpq_add_z Rmpq_sub_z Rmpq_z_sub Rmpq_mul_z Rmpq_div_z Rmpq_z_div
 Rmpq_pow_ui
@@ -75,35 +78,14 @@ qgmp_randinit_set qgmp_randinit_default_nobless qgmp_randinit_mt_nobless
 qgmp_randinit_lc_2exp_nobless qgmp_randinit_lc_2exp_size_nobless qgmp_randinit_set_nobless
 qgmp_urandomb_ui qgmp_urandomm_ui
     );
-    our $VERSION = '0.52';
+
+    @Math::GMPq::EXPORT_OK = (@untagged, @tagged);
+    our $VERSION = '0.53';
     #$VERSION = eval $VERSION;
 
     Math::GMPq->DynaLoader::bootstrap($VERSION);
 
-    %Math::GMPq::EXPORT_TAGS =(mpq => [qw(
-GMPQ_PV_NV_BUG
-Rmpq_abs Rmpq_add Rmpq_canonicalize Rmpq_clear Rmpq_cmp Rmpq_cmp_si Rmpq_cmp_ui
-Rmpq_cmp_z Rmpq_add_z Rmpq_sub_z Rmpq_z_sub Rmpq_mul_z Rmpq_div_z Rmpq_z_div
-Rmpq_pow_ui
-Rmpq_create_noval Rmpq_denref Rmpq_div Rmpq_div_2exp Rmpq_equal
-Rmpq_fprintf
-Rmpq_get_d
-Rmpq_get_den Rmpq_get_num Rmpq_get_str Rmpq_init Rmpq_init_nobless Rmpq_inp_str
-Rmpq_inv Rmpq_mul Rmpq_mul_2exp Rmpq_neg Rmpq_numref Rmpq_out_str Rmpq_printf
-Rmpq_set Rmpq_set_d Rmpq_set_den Rmpq_set_f Rmpq_set_num Rmpq_set_si Rmpq_set_str
-Rmpq_set_NV Rmpq_get_NV Rmpq_cmp_NV
-Rmpq_set_IV Rmpq_cmp_IV
-Rmpq_set_ui Rmpq_set_z Rmpq_sgn
-Rmpq_sprintf Rmpq_snprintf
-Rmpq_sub Rmpq_swap
-Rmpq_integer_p
-TRmpq_out_str TRmpq_inp_str
-qgmp_randseed qgmp_randseed_ui qgmp_randclear
-qgmp_randinit_default qgmp_randinit_mt qgmp_randinit_lc_2exp qgmp_randinit_lc_2exp_size
-qgmp_randinit_set qgmp_randinit_default_nobless qgmp_randinit_mt_nobless
-qgmp_randinit_lc_2exp_nobless qgmp_randinit_lc_2exp_size_nobless qgmp_randinit_set_nobless
-qgmp_urandomb_ui qgmp_urandomm_ui
-)]);
+    %Math::GMPq::EXPORT_TAGS =(mpq => \@tagged);
 
 sub dl_load_flags {0} # Prevent DynaLoader from complaining and croaking
 
